==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/net/fusenshiserversocket.cpp <==
/*
 * $Id: fusenshiserversocket.cpp,v 1.1 2005/12/02 07:08:00 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "../include/fusenshi.h"
#include "fusenshiserversocket.h"

//_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
class FusenshiServerConnectedSocket : public FusenshiSocket
{
public:
    FusenshiServerConnectedSocket(int sock)
    {
        m_socket = sock;
    }

    virtual ~FusenshiServerConnectedSocket()
    {
    }

    virtual ssize_t recv(void* buf, size_t len)
    {
        return ::recv(m_socket, buf, len, 0);
    }
    
    virtual ssize_t send(const void* buf, size_t len)
    {
        return ::send(m_socket, buf, len, 0);
    }
};

//_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
FusenshiServerSocket::FusenshiServerSocket(int port)
{
    // ХåȤι
    m_socket = socket(PF_INET, SOCK_STREAM, 0);

    if (-1 == m_socket) {
        throw "socket() failed.";
    }
    
    int optval = 1;
    struct sockaddr_in saddr;

    memset(&saddr, 0, sizeof(saddr));
    saddr.sin_port = htons(port);
    saddr.sin_family = PF_INET;
    saddr.sin_addr.s_addr = htonl(INADDR_ANY);

    if (setsockopt(m_socket, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof(optval))) {
        close();
        throw "setsockopt() failed.";
    }

    if (bind(m_socket, (struct sockaddr *)&saddr, sizeof(saddr))) {
        close();
        throw "bind() failed.";
    }
}

FusenshiServerSocket::~FusenshiServerSocket()
{
}

int FusenshiServerSocket::listen(int backlog)
{
    return ::listen(m_socket, backlog);
}

RefPtr<FusenshiSocket> FusenshiServerSocket::accept
    (struct sockaddr * addr, socklen_t * addrlen)
{
    int cs = ::accept(m_socket, addr, addrlen);
    
    if (0 <= cs) {
        return RefPtr<FusenshiSocket>(new FusenshiServerConnectedSocket(cs));
    }
    
    return RefPtr<FusenshiSocket>();
}

ssize_t FusenshiServerSocket::recv(void* buf, size_t len)
{
    return -1;
}

ssize_t FusenshiServerSocket::send(const void* buf, size_t len)
{
    return -1;
}

==> fusenshi-0.9.0.tgz: fusenshi-0.9.0/src/net/fusenshiserversocket.cpp <==
/*
 * $Id: fusenshiserversocket.cpp,v 1.2 2007/06/25 06:19:21 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "../include/fusenshi.h"
#include "fusenshiserversocket.h"

//_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
class FusenshiServerConnectedSocket : public FusenshiSocket
{
public:
    FusenshiServerConnectedSocket(int sock)
    {
        m_socket = sock;
    }

    virtual ~FusenshiServerConnectedSocket()
    {
    }

    virtual ssize_t recv(void* buf, size_t len)
    {
        return ::recv(m_socket, buf, len, 0);
    }
    
    virtual ssize_t send(const void* buf, size_t len)
    {
        return ::send(m_socket, buf, len, 0);
    }
};

//_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
FusenshiServerSocket::FusenshiServerSocket(int port)
{
    // ХåȤι
    m_socket = socket(AF_INET, SOCK_STREAM, 0);

    if (-1 == m_socket) {
        throw "socket() failed.";
    }
    
    int optval = 1;
    struct sockaddr_in saddr;

    memset(&saddr, 0, sizeof(saddr));
    saddr.sin_port = htons(port);
    saddr.sin_family = AF_INET;
    saddr.sin_addr.s_addr = htonl(INADDR_ANY);

    if (setsockopt(m_socket, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof(optval))) {
        close();
        throw "setsockopt() failed.";
    }

    if (bind(m_socket, (struct sockaddr *)&saddr, sizeof(saddr))) {
        close();
        throw "bind() failed.";
    }
}

FusenshiServerSocket::~FusenshiServerSocket()
{
}

int FusenshiServerSocket::listen(int backlog)
{
    return ::listen(m_socket, backlog);
}

RefPtr<FusenshiSocket> FusenshiServerSocket::accept
    (struct sockaddr * addr, socklen_t * addrlen)
{
    int cs = ::accept(m_socket, addr, addrlen);
    
    if (0 <= cs) {
        return RefPtr<FusenshiSocket>(new FusenshiServerConnectedSocket(cs));
    }
    
    return RefPtr<FusenshiSocket>();
}

ssize_t FusenshiServerSocket::recv(void* buf, size_t len)
{
    return -1;
}

ssize_t FusenshiServerSocket::send(const void* buf, size_t len)
{
    return -1;
}
